# USGS Earthquake Hazard Toolbox

Angular web applications for exploring hazard, disaggregations, ground motion models,
magnitude frequency distributions, and other earthquake hazard attributes.

The web applications utilize various web services from
[nshmp-haz](https://code.usgs.gov/ghsc/nshmp/nshmp-haz),
[nshmp-ws](https://code.usgs.gov/ghsc/nshmp/nshmp-ws),
[nshmp-ws-static](https://code.usgs.gov/ghsc/nshmp/nshmp-ws-static), and other sources.

The codebase, collectively called the USGS Earthquake Hazard Toolbox,
replaces the [Unified Hazard Toolbox (UHT)](https://earthquake.usgs.gov/hazards/interactive/).

The USGS Earthquake Hazard Toolbox can be found at <https://earthquake.usgs.gov/nshmp/>.

The current published version of the code is
[1.0.0](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tags/1.0.0) with IPDS record: IP-151856.

Suggested citation: Clayton, B.S., Powers, P.M., 2023, nshmp-apps:
USGS Earthquake Hazard Toolbox. U.S. Geological Survey
software release, doi: [10.5066/P9UAIISF](https://doi.org/10.5066/P9UAIISF).

## Contents

- [Documentation and User guide](#documenation-and-user-guide)
  - [Repository Documentation](#repository-documentation)
  - [Angular USGS Earthquake Hazard Toolbox Documentation](#angular-usgs-earthquake-hazard-toolbox-documentation)
- [USGS Earthquake Hazard Toolbox Applications](#usgs-earthquake-hazard-toolbox-applications)
  - [Applications](#applications)
    - [USGS Earthquake Hazard Toolbox Dashboard](#usgs-earthquake-hazard-toolbox-dashboard)
    - [Hazard Applications](#hazard-applications)
    - [Ground Motion Models Applications](#ground-motion-model-applications)
    - [Source Model Applications](#source-model-applications)
    - [Services Application](#services-application)
- [Commands](#commands)

## Documenation and User Guide

Repository and Angular documentation:

- <https://ghsc.code-pages.usgs.gov/nshmp/nshmp-apps/>

### Repository Documentation

General documentation about this repository and development.

- <https://ghsc.code-pages.usgs.gov/nshmp/nshmp-apps/additional-documentation/repository-documentation.html>

### Angular USGS Earthquake Hazard Toolbox Documentation

Documentation on each application in the USGS Earthquake Hazard Toolbox.

- <https://ghsc.code-pages.usgs.gov/nshmp/nshmp-apps/apps>

## USGS Earthquake Hazard Toolbox Applications

The Angular applications collectivly create the
[USGS Earthquake Hazard Toolbox](https://earthquake.usgs.gov/nshmp/).

### Applications

#### USGS Earthquake Hazard Toolbox Dashboard

- Web application: <https://earthquake.usgs.gov/nshmp/>
- [Source code](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main/projects/nshmp-apps/src/app/dashboard)

|                                               |                                                      |
| --------------------------------------------- | ---------------------------------------------------- |
| ![Dashboard](screenshots/apps/dashboard.jpeg) | ![About page](screenshots/apps/dashboard-about.jpeg) |

#### Hazard Applications

##### Disaggregation

- Web application: <https://earthquake.usgs.gov/nshmp/hazard/disagg>
- [Source code](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main/projects/nshmp-apps/src/app/hazard/disagg)

|                                                 |                                                  |
| ----------------------------------------------- | ------------------------------------------------ |
| ![Disaggregation](screenshots/apps/disagg.jpeg) | ![Summary](screenshots/apps/disagg-summary.jpeg) |

##### Dynamic Hazard Calculations

- Web application: <https://earthquake.usgs.gov/nshmp/hazard/dynamic>
- [Source code](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main/projects/nshmp-apps/src/app/hazard/dynamic)

|                                                         |                                                        |
| ------------------------------------------------------- | ------------------------------------------------------ |
| ![Dynamic Hazard](screenshots/apps/dynamic-hazard.jpeg) | ![Summary](screenshots/apps/dynamic-hazard-table.jpeg) |

##### Static Hazard

- Web application: <https://earthquake.usgs.gov/nshmp/hazard/static>
- [Source code](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main/projects/nshmp-apps/src/app/hazard/static)

|                                                       |                                                     |
| ----------------------------------------------------- | --------------------------------------------------- |
| ![Static Hazard](screenshots/apps/static-hazard.jpeg) | ![Table](screenshots/apps/static-hazard-table.jpeg) |

#### Ground Motion Model Applications

##### Ground Motion vs. Distance

- Web application: <https://earthquake.usgs.gov/nshmp/gmm/distance>
- [Source code](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main/projects/nshmp-apps/src/app/gmm/distance)

|                                                     |                                                    |
| --------------------------------------------------- | -------------------------------------------------- |
| ![GMM Distance](screenshots/apps/gmm-distance.jpeg) | ![Table](screenshots/apps/gmm-distance-table.jpeg) |

##### Ground Motion vs. Magnitude

- Web application: <https://earthquake.usgs.gov/nshmp/gmm/magnitude>
- [Source code](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main/projects/nshmp-apps/src/app/gmm/magnitude)

|                                                       |                                                     |
| ----------------------------------------------------- | --------------------------------------------------- |
| ![GMM Magnitude](screenshots/apps/gmm-magnitude.jpeg) | ![Table](screenshots/apps/gmm-magnitude-table.jpeg) |

##### Response Spectra

- Web application: <https://earthquake.usgs.gov/nshmp/gmm/spectra>
- [Source code](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main/projects/nshmp-apps/src/app/gmm/spectra)

|                                           |                                               |
| ----------------------------------------- | --------------------------------------------- |
| ![Spectra](screenshots/apps/spectra.jpeg) | ![Table](screenshots/apps/spectra-table.jpeg) |

#### Source Model Applications

##### Model Mapping

- Web application: <https://earthquake.usgs.gov/nshmp/source/model-maps>
- [Source code](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main/projects/nshmp-apps/src/app/source/model-maps)

|                                                      |                                                          |
| ---------------------------------------------------- | -------------------------------------------------------- |
| ![Model Mapping](screenshots/apps/data-mapping.jpeg) | ![Layers](screenshots/apps/data-mapping-all-layers.jpeg) |

##### Magnitude Frequency Distribution

- Web application: <https://earthquake.usgs.gov/nshmp/source/mfd>
- [Source code](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main/projects/nshmp-apps/src/app/source/mfd)

|                                   |                                                     |
| --------------------------------- | --------------------------------------------------- |
| ![MFD](screenshots/apps/mfd.jpeg) | ![Logic tree](screenshots/apps/mfd-logic-tree.jpeg) |

#### Services Application

- Web application: <https://earthquake.usgs.gov/nshmp/services>
- [Source code](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main/projects/nshmp-apps/src/app/services)

|                                             |                                               |
| ------------------------------------------- | --------------------------------------------- |
| ![Services](screenshots/apps/services.jpeg) | ![Services](screenshots/apps/services-2.jpeg) |

## Commands

- General NPM commands:
  - Install dependencies: `npm ci`
  - Lint: `npm run lint`
  - Lint Fix: `npm run fix`
  - Unit tests: `npm run test`
- Angular Commands
  - Start application: `npm run start`
  - Build application: `npm run build`
  - Production build: `npm run build:prod`
  - Serve production build locally: `npm run start:prod`
- Documentation Commands
  - Build Compodocs: `npm run compodoc:build`
  - Build and serve Compodocs: `npm run compodoc:start`
