# Docker

## Local Build

This projects contains a
[Dockerfile](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/blob/main/Dockerfile)
that can be built and ran.

### Build Docker Image

```bash
docker build \
  --build-arg BASE_HREF=<some/path> \
  nshmp-apps .
```

> Note: Replace `<some/path>` with an appropritate base href

Example:

```bash
docker build \
  --build-arg BASE_HREF=nshmp \
  nshmp-apps .
```

### Run Docker Image

```bash
docker run -p <PORT>:8080 nshmp-apps
```

> Note: Replace `<PORT>` with an appropriate port to run the application.

Example:

```bash
docker run -p 8080:8080 nshmp-apps
```

## Docker Registry

_nshmp-apps_ is available as a public image from the
[GitLab registry](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/container_registry) with tags:

- `latest`,`staging-latest`: Latest updates associated with the
  [main](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main) branch
- `production-latest`: Latest stable release associated with a
  [tag](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tags)

### Pull Image

To ensure you have the latest _nshmp-apps_ update associated with a specific tag,
always first pull the image from Docker:

```bash
docker pull code.usgs.gov:5001/ghsc/nshmp/nshmp-apps/nshmp-apps:<tag>
```

> Replace `<tag>` with one of the above tags.

Example:

```bash
docker pull code.usgs.gov:5001/ghsc/nshmp/nshmp-apps/nshmp-apps:latest
```

### Run Registry Image

```bash
docker run -p 8080:8080 code.usgs.gov:5001/ghsc/nshmp/nshmp-apps/nshmp-apps:latest
```

## Docker Environment Variables

By default the backend web services that nshmp-apps calls use
`https://earthquake.usgs.gov` as the default, this can be changed by setting
the `BASE_SERVICE_URL` environment variable:

```bash
docker run -p 8080:8080 -e BASE_SERVICE_URL="" code.usgs.gov:5001/ghsc/nshmp/nshmp-apps/nshmp-apps:latest
```

<br>
<div align="center">
  <h3> 
    Previous: <a href="https://ghsc.code-pages.usgs.gov/nshmp/nshmp-apps/additional-documentation/web-service-configuration.html">Web Service Configuration</a> &emsp; &emsp;
    Next: <a href="https://ghsc.code-pages.usgs.gov/nshmp/nshmp-apps/additional-documentation/development.html">Development</a>
  </h3>
</div>
