# Project Structure

## Angular Application

All NSHMP applications reside in the
[nshmp-apps](https://code.usgs.gov/ghsc/nshmp/nshmp-apps/-/tree/main/projects/nshmp-apps)
Angular project.

### nshmp-apps Structure

The NSHMP applications are organized such that the directories and applications match
the url path:

<div class="mermaid">
  graph LR
    root[". <br>/projects/nshmp-apps/src/app"] --> /dashboard["/dashboard <br>USGS Earthquake Hazard Toolbox Dashboard"]
    root[". <br>/projects/nshmp-apps/src/app"] --> /hazard["/hazard <br>Hazard Applications"]
    root[". <br>/projects/nshmp-apps/src/app"] --> /gmm["/gmm <br>GMM Applications"]
    root[". <br>/projects/nshmp-apps/src/app"] --> /source["/source <br>Source Model Applications"]
    root[". <br>/projects/nshmp-apps/src/app"] --> /dev["/dev <br>Development Applications"]
    root[". <br>/projects/nshmp-apps/src/app"] --> /services["/services <br> Services Application"]
    %% Hazard applications
    /hazard --> /disagg["/disagg <br>Disaggregations"]
    /hazard --> /dynamic["/dynamic <br>Dynamic Hazard Curves"]
    /hazard --> /static["/static <br>Static Hazard Curves"]
    %% GMM applications
    /gmm --> /distance["/distance <br>Ground Motion vs. Distance"]
    /gmm --> /magnitude["/magnitude <br>Ground Motion vs. Magnitude"]
    /gmm --> /spectra["/spectra <br>Response Spectra"]
    %% Source model applications
    /source --> /data["/data <br>Model Mapping"]
    /source --> /mfd["/mfd <br>Magnitude Frequency Distribution"]
    %% Development applications
    /dev --> /dev-dashboard["/dashboard <br> Development Dashboard"]
    /dev --> /aws["/aws <br>AWS Applications"]
    /dev --> /math["/math <br>Math Applications"]
    %% AWS development applications
    /aws --> /check-haz-jobs["/check-haz-jobs <br>Check Hazard Jobs <br>Running in AWS"]
    /aws --> /haz-job-history["/haz-job-history <br>History of hazard jobs"]
    /aws --> /submit-haz-jobs["/submit-haz-jobs <br>Run Hazard Code in AWS"]
    /aws --> /terminate-haz-jobs["/terminate-haz-jobs <br>Terminate hazard job"]
    %% Math development applications
    /math --> /exceedance-explorer["/exceedance-explorer <br>Explorer Exceedance Calculations"]
</div>

### A Single Application

Each application should follow the same heirarchy:

<div class="mermaid">
  graph LR
    some-application --> components["components <br>Define Angular components"]
    some-application --> models["models <br>TypeScript interfaces"]
    some-application --> state["state <br>State files"]
    some-application --> utils["utils <br>Application utilities"]
    some-application --> html["app.component.html <br>Application entry component HTML"]
    some-application --> scss["app.component.scss <br>Application entry styling"]
    some-application --> ts["app.component.ts <br>Application entry component TypeScript"]
    some-application --> module["some-application.module.ts <br>Application module and route"]
</div>

<br>
<div align="center">
  <h3> 
    Previous: <a href="https://ghsc.code-pages.usgs.gov/nshmp/nshmp-apps/additional-documentation/technologies-used.html">Technologies Used</a> &emsp; &emsp;
    Next: <a href="https://ghsc.code-pages.usgs.gov/nshmp/nshmp-apps/additional-documentation/web-service-configuration.html">Web Service Configuration</a>
  </h3>
</div>

<script type="module">
  import mermaid from 'https://cdn.jsdelivr.net/npm/mermaid@10/dist/mermaid.esm.min.mjs';
  mermaid.initialize({ startOnLoad: true });
</script>
