#!/bin/bash

NGINX_CONF_DIR=${NGINX_CONF_DIR:-'.'};

# Write configuration file for NGINX
cat << EOF > "${NGINX_CONF_DIR}/00-server.conf"
location /nshmp {
  add_header 'X-Frame-Options' 'DENY';
  add_header 'X-Content-Type-Options' 'nosniff';
  add_header 'Cache-Control' 'public';
  add_header 'Access-Control-Allow-Origin' '*';
  add_header 'Access-Control-Allow-Methods' '*';
  add_header 'Access-Control-Allow-Headers' '*';

  expires 5m;

  # css/js are hash-stamped, and url will change if content changes
  location ~* /nshmp/(.*)\\.(css|js)\$ {
    expires 1y;
    try_files \$uri /nshmp/previous/\$1.\$2;
  }

  try_files \$uri \$uri/ \$uri.html \$uri/index.html @nshmp-angular-fallback;
}

location @nshmp-angular-fallback {
  rewrite  ^(.*)\$  /nshmp/index.html last;
}
EOF

cat << EOF > "${NGINX_CONF_DIR}/01-server.conf"
location /ws/nshmp {
  add_header 'X-Frame-Options' 'DENY';
  add_header 'X-Content-Type-Options' 'nosniff';
  add_header 'Cache-Control' 'public';
  add_header 'Access-Control-Allow-Origin' '*';
  add_header 'Access-Control-Allow-Methods' '*';
  add_header 'Access-Control-Allow-Headers' '*';

  expires 5m;

  # css/js are hash-stamped, and url will change if content changes
  location ~* /ws/nshmp/(.*)\\.(css|js)\$ {
    expires 1y;
    try_files \$uri /ws/nshmp/previous/\$1.\$2;
  }

  try_files \$uri \$uri/ \$uri.html \$uri/index.html @swagger-angular-fallback;
}

location @swagger-angular-fallback {
  rewrite  ^(.*)\$  /ws/nshmp/index.html last;
}
EOF

cat << EOF > "${NGINX_CONF_DIR}/02-server.conf"
location /ws/designmaps/aashto-2023 {
  add_header 'X-Frame-Options' 'DENY';
  add_header 'X-Content-Type-Options' 'nosniff';
  add_header 'Cache-Control' 'public';
  add_header 'Access-Control-Allow-Origin' '*';
  add_header 'Access-Control-Allow-Methods' '*';
  add_header 'Access-Control-Allow-Headers' '*';

  expires 5m;

  # css/js are hash-stamped, and url will change if content changes
  location ~* /ws/designmaps/aashto-2023/(.*)\\.(css|js)\$ {
    expires 1y;
    try_files \$uri /ws/designmaps/previous/\$1.\$2;
  }

  try_files \$uri \$uri/ \$uri.html \$uri/index.html @aashto-angular-fallback;
}

location @aashto-angular-fallback {
  rewrite  ^(.*)\$  /ws/designmaps/aashto-2023/index.html last;
}
EOF
