import {navigation} from '../../../../src/shared/utils/navigation.utils';
import * as utils from '../../../utils';

const url = 'https://**/ws/nshmp/*/static/hazard';

describe('Static Hazard Application', () => {
  beforeEach(() => {
    cy.viewport('macbook-16');
    cy.intercept(url).as('usage');
    cy.visit('/hazard/static');
    cy.wait('@usage');
  });

  describe('Check nshmp-template', () => {
    utils.hasNshmpTemplate(navigation());
  });

  describe('Application', () => {
    utils.hasControlPanel();
    utils.hasPlotContent();
    utils.toggleControlPanel();
    utils.togglePlotPanel();
    utils.toggleSettingPanel();
    utils.hasHazardModelMenu();
    utils.changePlotSettings('.hazard-plot', '.hazard-settings');
    utils.changePlotSettings('.spectra-plot', '.spectra-settings');

    it('Can set control panel', () => {
      setControlPanel();
    });

    it('Calls service and plots response', () => {
      const buttons: utils.ControlPanelButtons = {
        hasResetButton: false,
        hasServiceCallButton: true,
        hasSubmitButton: true,
      };
      utils.controlPanelButtonsNotEnabled(buttons);

      setControlPanel();

      utils.submitFormCheckPlots({
        firstPlotClass: '.hazard-plot',
        secondPlotClass: '.spectra-plot',
      });

      utils.controlPanelButtonsEnabled(buttons);
    });

    describe('Application Tabs', () => {
      it('Has plot tab', () => {
        cy.get('plotly-plot');

        utils.hasApplicationTab('.hazard-tab');

        cy.get('plotly-plot').should('not.exist');

        utils.hasApplicationTab('.plots-tab');

        cy.get('plotly-plot');
      });

      it('Has medians tab', () => {
        cy.get('plotly-plot');

        utils.exportDataTableNotExist();
        utils.dataTableNotExist();

        setControlPanel();

        utils.submitFormCheckPlots({
          firstPlotClass: '.hazard-plot',
          secondPlotClass: '.spectra-plot',
        });

        utils.hasApplicationTab('.hazard-tab');

        cy.get('plotly-plot').should('not.exist');

        utils.hasExportDataTable(
          'static-hazard-curves-CONUS_2018-(-118,34).csv',
        );
        utils.hasDataTable();
      });

      it('Has spectra tab', () => {
        cy.get('plotly-plot');

        utils.exportDataTableNotExist();
        utils.dataTableNotExist();

        setControlPanel();

        utils.submitFormCheckPlots({
          firstPlotClass: '.hazard-plot',
          secondPlotClass: '.spectra-plot',
        });

        utils.hasApplicationTab('.spectra-tab');

        cy.get('plotly-plot').should('not.exist');

        utils.hasExportDataTable(
          'static-hazard-spectra-CONUS_2018-(-118,34).csv',
        );
        utils.hasDataTable();
      });
    });
  });
});

function setControlPanel() {
  utils.setHazardCommonControlPanel();
  utils.setHazardMaxDirection();
  utils.setHazardTruncate();
}
