import {navigation} from '../../../../src/shared/utils/navigation.utils';
import * as utils from '../../../utils';

const url = 'https://earthquake.usgs.gov/ws/nshmp/*/dynamic/trees';

describe('Magnitude Frequency Distribution Application', () => {
  beforeEach(() => {
    cy.viewport('macbook-16');
    cy.intercept(url).as('usage');
    cy.visit('/source/mfd');
    cy.wait('@usage');
  });

  describe('Check nshmp-template', () => {
    utils.hasNshmpTemplate(navigation());
  });

  describe('Application', () => {
    utils.hasControlPanel();
    utils.hasPlotContent();
    utils.toggleControlPanel();
    utils.togglePlotPanel();
    utils.toggleSettingPanel();
    utils.hasHazardModelMenu();
    utils.changePlotSettings('.mfd-plot', '.mfd-settings');

    it('Can set control panel', () => {
      setControlPanel();
    });

    it('Calls service and plots response', () => {
      const buttons: utils.ControlPanelButtons = {
        hasResetButton: false,
        hasServiceCallButton: true,
        hasSubmitButton: true,
      };
      utils.controlPanelButtonsNotEnabled(buttons);

      setControlPanel();

      utils.submitFormCheckPlot({
        plotClass: '.mfd-plot',
      });

      utils.controlPanelButtonsEnabled(buttons);
    });

    describe('Application Tabs', () => {
      it('Has plot tab', () => {
        utils.hasApplicationTab('.plots-tab');
        cy.get('plotly-plot');
      });

      it('Has data tab', () => {
        cy.get('plotly-plot');

        utils.exportDataTableNotExist();
        utils.dataTableNotExist();

        setControlPanel();

        utils.submitFormCheckPlot({
          plotClass: '.mfd-plot',
        });

        utils.hasApplicationTab('.data-tab');

        cy.get('plotly-plot').should('not.exist');

        utils.hasExportDataTable(
          'mfd-active_crust-fault-gore_range_frontal.csv',
        );
        utils.hasDataTable();
      });
    });
  });
});

function setControlPanel() {
  setModel();
  setSource();
  setSourceTree();
}

function setModel() {
  cy.get('nshmp-template-control-panel')
    .find('hazard-lib-model-form')
    .scrollIntoView()
    .find('mat-select')
    .click();
  utils.selectMatOption('CONUS_2018');
}

function setSource() {
  cy.get('nshmp-template-control-panel')
    .find('.source-select')
    .scrollIntoView()
    .find('mat-select')
    .click();
  utils.selectMatOption('ACTIVE_CRUST::FAULT');
}

function setSourceTree() {
  cy.get('nshmp-template-control-panel')
    .find('.source-tree-select')
    .scrollIntoView()
    .find('mat-select')
    .click();
  utils.selectMatOption('2100');
}
