import {Routes} from '@angular/router';

import {designMapsRoutes} from './designmaps/design-maps.routes';
import {devRoutes} from './dev/dev.routes';
import {errorRoutes} from './error-pages/error-pages.routes';
import {gmmRoutes} from './gmm/gmm.routes';
import {hazardRoutes} from './hazard/hazard.routes';
import {internalRoutes} from './internal/internal.routes';
import {ncmRoutes} from './ncm/ncm.routes';
import {sourceRoutes} from './source/source.routes';

/**
 * USGS Earthquake Hazard Toolbox routes
 */
const routes: Routes = [
  // Main dashboard application
  {
    loadComponent: () =>
      import('./dashboard/app.component').then(com => com.AppComponent),
    path: '',
  },
  // NCM applications
  {
    children: ncmRoutes(),
    data: {
      label: 'NCM',
    },
    path: 'ncm',
  },
  // Design maps applications
  {
    children: designMapsRoutes(),
    data: {
      label: 'Design Maps',
    },
    path: 'designmaps',
  },
  // Development applications
  {
    children: devRoutes(),
    data: {
      label: 'Development',
    },
    path: 'dev',
  },
  // Ground motion model applications
  {
    children: gmmRoutes(),
    data: {
      label: 'GMM',
    },
    path: 'gmm',
  },
  // Hazard applications
  {
    children: hazardRoutes(),
    data: {
      label: 'Hazard',
    },
    path: 'hazard',
  },
  // Internal applications
  {
    children: internalRoutes(),
    data: {
      label: 'Internal',
    },
    path: 'internal',
  },
  // Source model applications
  {
    children: sourceRoutes(),
    data: {
      label: 'Source Model',
    },
    path: 'source',
  },
  // Error pages for reverse proxy errors
  {
    children: errorRoutes(),
    data: {
      label: 'Error Page',
    },
    path: 'error-pages',
  },
  // Catch all
  {
    path: '**',
    redirectTo: '',
  },
];

/**
 * Return USGS earthquake hazard toolbox /nshmp routes.
 */
export function appRoutes(): Routes {
  return routes;
}
