import {Component, computed, input, OnDestroy, OnInit} from '@angular/core';
import {FormControl, ReactiveFormsModule} from '@angular/forms';
import {MatFormFieldModule} from '@angular/material/form-field';
import {MatSelectModule} from '@angular/material/select';
import {Subscription} from 'rxjs';

import {AppService} from '../../services/app.service';

@Component({
  imports: [MatFormFieldModule, ReactiveFormsModule, MatSelectModule],
  selector: 'app-building-code-control',
  styleUrl: './building-code-control.component.scss',
  templateUrl: './building-code-control.component.html',
})
export class BuildingCodeControlComponent implements OnInit, OnDestroy {
  readonly control = input.required<FormControl<string>>();

  buildingCodes = computed(
    () => this.service.usage()?.response.parameters.building_code.values,
  );

  parameters = computed(() => this.service.usage()?.response.parameters);

  private subs: Subscription[] = [];

  constructor(public service: AppService) {}

  ngOnInit(): void {
    this.subs.push(
      this.service.formGroup.controls.buildingCode.valueChanges.subscribe(
        buildingCode => {
          const values = this.service.hazardFormGroup.getRawValue();

          if (values.buildingCode !== buildingCode) {
            this.service.hazardFormGroup.patchValue({buildingCode});
          }
        },
      ),
    );

    this.subs.push(
      this.service.hazardFormGroup.controls.buildingCode.valueChanges.subscribe(
        buildingCode => {
          const values = this.service.formGroup.getRawValue();

          if (values.buildingCode !== buildingCode) {
            this.service.formGroup.patchValue({buildingCode});
          }
        },
      ),
    );
  }

  ngOnDestroy(): void {
    this.subs.forEach(sub => sub.unsubscribe());
  }
}
