import {Component, computed, OnDestroy, OnInit} from '@angular/core';
import {ReactiveFormsModule} from '@angular/forms';
import {MatButtonModule} from '@angular/material/button';
import {MatError, MatHint, MatInputModule} from '@angular/material/input';
import {MatFormField, MatSelectModule} from '@angular/material/select';
import {
  NshmpLibNgControlPanelButtonsComponent,
  NshmpService,
} from '@ghsc/nshmp-lib-ng/nshmp';
import {Subscription} from 'rxjs';

import {AppService} from '../../services/app.service';
import {BuildingCodeControlComponent} from '../building-code-control/building-code-control.component';

@Component({
  imports: [
    MatFormField,
    MatSelectModule,
    MatInputModule,
    ReactiveFormsModule,
    MatButtonModule,
    NshmpLibNgControlPanelButtonsComponent,
    MatHint,
    MatError,
    BuildingCodeControlComponent,
  ],
  selector: 'app-control-panel-input',
  styleUrl: './control-panel-input.component.scss',
  templateUrl: './control-panel-input.component.html',
})
export class ControlPanelInputComponent implements OnInit, OnDestroy {
  formGroup = this.service.formGroup;

  parameters = computed(() => this.service.usage()?.response.parameters);

  subs: Subscription[] = [];

  constructor(
    public service: AppService,
    private nshmpService: NshmpService,
  ) {}

  ngOnInit(): void {
    const controls = this.formGroup.controls;

    this.subs.push(
      controls.afe.valueChanges.subscribe(() => this.service.resetState()),
    );

    this.subs.push(
      controls.buildingCode.valueChanges.subscribe(() =>
        this.service.resetState(),
      ),
    );

    this.subs.push(
      controls.iml.valueChanges.subscribe(() => this.service.resetState()),
    );
  }

  ngOnDestroy(): void {
    this.subs.forEach(sub => sub.unsubscribe());
  }

  /**
   * On form submit.
   */
  onSubmit(): void {
    this.service.callService();
    this.nshmpService.selectPlotControl();
  }
}
