import {Component, computed, OnDestroy, OnInit} from '@angular/core';
import {MatDivider} from '@angular/material/divider';
import {MatExpansionModule} from '@angular/material/expansion';
import {
  NshmpLibNgAlertComponent,
  NshmpLibNgAppMetadataComponent,
} from '@ghsc/nshmp-lib-ng/nshmp';
import {
  NshmpLibNgPlotComponent,
  NshmpLibNgPlotsContainerComponent,
} from '@ghsc/nshmp-lib-ng/plot';
import {Subscription} from 'rxjs';

import {AppService} from '../../services/app.service';
import {ParameterSummaryComponent} from '../parameter-summary/parameter-summary.component';
import {RiskTargetsComponent} from '../risk-targets/risk-targets.component';
import {RtgmSummaryComponent} from '../rtgm-summary/rtgm-summary.component';

@Component({
  imports: [
    NshmpLibNgPlotsContainerComponent,
    NshmpLibNgPlotComponent,
    NshmpLibNgAppMetadataComponent,
    NshmpLibNgAlertComponent,
    MatExpansionModule,
    MatDivider,
    ParameterSummaryComponent,
    RiskTargetsComponent,
    RtgmSummaryComponent,
  ],
  selector: 'app-plots',
  styleUrl: './plots.component.scss',
  templateUrl: './plots.component.html',
})
export class PlotsComponent implements OnInit, OnDestroy {
  plots = computed(() => [
    this.service.plots().hazard,
    this.service.plots().fragility,
    this.service.plots().derivativeFragility,
    this.service.plots().hazardFragility,
    this.service.plots().integralHazardFragility,
  ]);

  serviceResponse = this.service.serviceResponse;

  /** Repo metadata */
  repositories = computed(() => this.service.usage()?.metadata.repositories);

  private sub = new Subscription();

  constructor(private service: AppService) {}

  ngOnInit(): void {
    this.sub = this.service.formGroup.controls.label.valueChanges.subscribe(
      label => this.onLabel(label),
    );
  }

  ngOnDestroy(): void {
    this.sub.unsubscribe();
  }

  private onLabel(label: string): void {
    const hazard = this.service.plots().hazard;
    hazard.plotData.data.forEach(data => (data.name = label));
  }
}
