import {Component, computed} from '@angular/core';
import {
  NshmpLibNgDataTableComponent,
  TableData,
} from '@ghsc/nshmp-lib-ng/nshmp';
import {RtgmSummary} from '@ghsc/nshmp-utils-ts/libs/erp/rtgm';

import {AppService} from '../../services/app.service';

@Component({
  imports: [NshmpLibNgDataTableComponent],
  selector: 'app-rtgm-summary',
  styleUrl: './rtgm-summary.component.scss',
  templateUrl: './rtgm-summary.component.html',
})
export class RtgmSummaryComponent {
  summaries = computed(() => this.service.serviceResponse()?.response.summary);

  constructor(private service: AppService) {}

  tableData(summaries: Record<string, RtgmSummary>): TableData[] {
    const {label} = this.service.formGroup.getRawValue();

    if (summaries && label in summaries) {
      const summary = summaries[label];

      return [
        {
          td: [`${summary.uhgm.toPrecision(4)} g`],
          th: 'Uniform hazard ground motion (UHGM)',
        },
        {
          td: [`${summary.rtgm.toFixed(4)} g`],
          th: 'Risk-targeted ground motion (RTGM)',
        },
        {
          td: [summary.riskCoeff.toPrecision(4)],
          th: 'Risk Coefficient (RTGM / UHGM)',
        },
        {
          td: [`${summary.colRisk_annual.toExponential(4)} yr^-1`],
          th: 'Annualized collapse risk',
        },
        {
          td: [summary.colRisk_T.toPrecision(4)],
          th: 'Collapse probability (decimal) over specified time horizon',
        },
        {
          td: [`${summary.timePeriod} years`],
          th: 'Time horizon over which collapse risk is to be determined',
        },
      ];
    } else {
      return [];
    }
  }
}
