import {Component, computed, Signal} from '@angular/core';
import {ReactiveFormsModule} from '@angular/forms';
import {MatDivider} from '@angular/material/divider';
import {
  MatAccordion,
  MatExpansionPanel,
  MatExpansionPanelHeader,
  MatExpansionPanelTitle,
} from '@angular/material/expansion';
import {MatLabel} from '@angular/material/form-field';
import {NshmpLibNgAppMetadataComponent} from '@ghsc/nshmp-lib-ng/nshmp';
import {
  NshmpLibNgPlotComponent,
  NshmpLibNgPlotsContainerComponent,
} from '@ghsc/nshmp-lib-ng/plot';
import {GmmUsageParameter} from '@ghsc/nshmp-utils-ts/libs/nshmp-ws/gmm-services';

import {Plots} from '../../models/state.model';
import {AppService} from '../../services/app.service';
import {FaultControlComponent} from '../fault-control/fault-control.component';
import {ParameterSummaryComponent} from '../parameter-summary/parameter-summary.component';

/**
 * Hangin wall effects plots with fault controls.
 *
 * Plots include:
 *  - Ground motion vs. distance
 *  - Fault
 */
@Component({
  imports: [
    NshmpLibNgPlotsContainerComponent,
    NshmpLibNgPlotComponent,
    NshmpLibNgAppMetadataComponent,
    MatAccordion,
    MatExpansionPanel,
    MatExpansionPanelHeader,
    MatExpansionPanelTitle,
    MatDivider,
    MatLabel,
    FaultControlComponent,
    ParameterSummaryComponent,
    ReactiveFormsModule,
  ],
  selector: 'app-plots',
  styleUrl: './plots.component.scss',
  templateUrl: './plots.component.html',
})
export class PlotsComponent {
  /** Usage parameters */
  private parameters = computed(
    () => this.service.state().usageResponse?.response?.parameters,
  );

  /** Ground motion plot */
  groundMotionPlotData = computed(
    () => this.service.state().plots?.get(Plots.GROUND_MOTION)?.plotData,
  );

  /** Fault plot */
  faultPlotData = computed(
    () => this.service.state().plots?.get(Plots.FAULT)?.plotData,
  );

  /** Control panel form field state */
  formState = this.service.controlPanelForm;

  /** Dip gmm parameter */
  dipParameter = computed(() => this.parameters()?.dip);

  /** Width gmm parameter with more restrictive max */
  widthParameter: Signal<GmmUsageParameter> = computed(() => ({
    ...this.parameters()?.width,
    max: 30,
  }));

  /** zTor gmm parameter with more restrictive max */
  zTorParameter: Signal<GmmUsageParameter> = computed(() => ({
    ...this.parameters()?.zTor,
    max: 10,
  }));

  /** Repo metadata */
  repositories = computed(
    () => this.service.state().usageResponse?.metadata.repositories,
  );

  constructor(private service: AppService) {}

  /**
   * Call services when fault controls change.
   */
  onFaultControlChange() {
    this.service.callService();
  }
}
