import {Component, computed, OnDestroy, OnInit} from '@angular/core';
import {ReactiveFormsModule} from '@angular/forms';
import {MatError, MatFormField, MatLabel} from '@angular/material/form-field';
import {MatInput} from '@angular/material/input';
import {combineLatest, Subscription} from 'rxjs';

import {AppService} from '../../services/app.service';

/**
 * Control panel form fields for GMM event parameters.
 */
@Component({
  imports: [MatLabel, MatFormField, MatInput, MatError, ReactiveFormsModule],
  selector: 'app-event-parameters',
  styleUrl: './event-parameters.component.scss',
  templateUrl: './event-parameters.component.html',
})
export class EventParametersComponent implements OnInit, OnDestroy {
  /** Form controls state */
  controls = this.service.formGroup.controls;

  /** Control panel form field state */
  form = this.service.formGroup;

  /** Usage parameters */
  parameters = computed(() => this.service.usage()?.response.parameters);

  private valueSubscription = new Subscription();

  constructor(private service: AppService) {}

  ngOnInit(): void {
    this.valueSubscription = combineLatest([
      this.controls.mMax.valueChanges,
      this.controls.mMin.valueChanges,
      this.controls.step.valueChanges,
    ]).subscribe(() => this.service.resetState());
  }

  ngOnDestroy(): void {
    this.valueSubscription.unsubscribe();
  }
}
