import {AsyncPipe} from '@angular/common';
import {Component, computed, OnDestroy, OnInit} from '@angular/core';
import {ReactiveFormsModule} from '@angular/forms';
import {MatError, MatFormField, MatLabel} from '@angular/material/form-field';
import {MatInput} from '@angular/material/input';
import {
  GmmFormControlIds,
  NshmpLibNgGmmMultiSelectComponent,
  VS30_COMMON_VALUES,
} from '@ghsc/nshmp-lib-ng/gmm';
import {combineLatest, Subscription} from 'rxjs';
import {map} from 'rxjs/operators';

import {AppService} from '../../services/app.service';

/**
 * Control panel form fields for GMM site parameters.
 */
@Component({
  imports: [
    NshmpLibNgGmmMultiSelectComponent,
    MatLabel,
    MatFormField,
    MatInput,
    MatError,
    AsyncPipe,
    ReactiveFormsModule,
  ],
  selector: 'app-site-parameters',
  styleUrl: './site-parameters.component.scss',
  templateUrl: './site-parameters.component.html',
})
export class SiteParametersComponent implements OnInit, OnDestroy {
  /** Form controls state */
  private controls = this.service.formGroup.controls;

  /** Common vs30 values */
  vs30CommonValues = VS30_COMMON_VALUES;

  /** Control panel form field state */
  form = this.service.formGroup;

  /** Usage parameters */
  parameters = computed(() => this.service.usage()?.response.parameters);

  /** Whether Vs30 is multi-selectable */
  vs30Multiple$ = this.controls.multiSelectableParam.valueChanges.pipe(
    map(
      multiSelectableParam =>
        multiSelectableParam.toString() === GmmFormControlIds.VS30.toString(),
    ),
  );

  private valueSubscription = new Subscription();

  constructor(private service: AppService) {}

  ngOnInit(): void {
    this.valueSubscription = combineLatest([
      this.controls.vs30Multi.valueChanges,
      this.controls.vs30.valueChanges,
      this.controls.z1p0.valueChanges,
      this.controls.z2p5.valueChanges,
      this.controls.zSed.valueChanges,
    ]).subscribe(() => this.service.resetState());
  }

  ngOnDestroy(): void {
    this.valueSubscription.unsubscribe();
  }
}
