import {Component, input} from '@angular/core';
import {MatButton} from '@angular/material/button';
import {MatDivider} from '@angular/material/divider';
import {MatList, MatListItem} from '@angular/material/list';
import {DisaggComponentData} from '@ghsc/nshmp-utils-ts/libs/nshmp-haz/www/disagg-service';

import {AppService} from '../../services/app.service';

/**
 * Lists of disaggregation summaries from service response.
 */
@Component({
  imports: [MatButton, MatDivider, MatList, MatListItem],
  selector: 'app-disagg-summary',
  styleUrl: './disagg-summary.component.scss',
  templateUrl: './disagg-summary.component.html',
})
export class DisaggSummaryComponent {
  /** Disaggregation component data state */
  readonly componentData = input.required<DisaggComponentData>();

  readonly showExportButton = input(true);

  /** Form field state */
  form = this.service.formGroup;

  constructor(public service: AppService) {}

  /**
   * Format data.
   *
   * @param data The data
   */
  dataValue(data: number | string) {
    if (typeof data === 'number' && data.toString().includes('.')) {
      const split = data.toString().split('.');
      if (split[0].length === 1 && split[1].length > 4) {
        data = data.toExponential(3);
      }
    }
    return data;
  }
}
