import {Component, computed} from '@angular/core';
import {MatDivider} from '@angular/material/divider';
import {MatList, MatListItem} from '@angular/material/list';
import {DisaggTarget, hazardUtils} from '@ghsc/nshmp-lib-ng/hazard';
import {nshmpUtils, returnPeriodAltName} from '@ghsc/nshmp-lib-ng/nshmp';

import {AppService} from '../../services/app.service';

/**
 * Summary of parameters entered, form field values to call service.
 */
@Component({
  imports: [MatDivider, MatList, MatListItem],
  selector: 'app-parameter-summary',
  styleUrl: './parameter-summary.component.scss',
  templateUrl: './parameter-summary.component.html',
})
export class ParameterSummaryComponent {
  /** Disaggregation target enum */
  DisaggTarget = DisaggTarget;

  Number = Number;

  isNaN = Number.isNaN;

  /** Return period value to name map */
  returnPeriodName = returnPeriodAltName;

  /** Place holder for select menus */
  selectPlaceHolder = nshmpUtils.selectPlaceHolder();

  /** Function to get display from a `Parameter` */
  toDisplay = nshmpUtils.parameterToDisplay;

  /** Disaggregation response data stat */
  disaggData = this.service.disaggData;

  /** Form field state */
  form = this.service.formGroup;

  /** Usage IMTs */
  imts = computed(() => this.service.usage()?.response.model.imts);

  /** The site classes as `Parameter`s */
  siteClasses = computed(() => {
    const usage = this.service.usage();

    if (usage) {
      return hazardUtils.siteClassesToParameters(
        usage.response.model.siteClasses,
      );
    }
  });

  constructor(public service: AppService) {}
}
