import {Component, computed} from '@angular/core';
import {MatList, MatListItem} from '@angular/material/list';
import {hazardUtils} from '@ghsc/nshmp-lib-ng/hazard';
import {nshmpUtils, returnPeriodAltName} from '@ghsc/nshmp-lib-ng/nshmp';

import {AppService} from '../../services/app.service';

/**
 * Summary of parameters entered, form field values to call service.
 */
@Component({
  imports: [MatList, MatListItem],
  selector: 'app-parameter-summary',
  styleUrl: './parameter-summary.component.scss',
  templateUrl: './parameter-summary.component.html',
})
export class ParameterSummaryComponent {
  isNaN = Number.isNaN;

  /** Return period value to name map */
  returnPeriodName = returnPeriodAltName;

  /** Place holder for select menus */
  selectPlaceHolder = nshmpUtils.selectPlaceHolder();

  /** Function to get display from a `Parameter` */
  toDisplay = nshmpUtils.parameterToDisplay;

  /** Form field state */
  formGroup = this.service.formGroup;

  /** Site classes from usage as `Parameter`s */
  siteClasses = computed(() => {
    const usage = this.service.usage();

    if (usage === undefined || usage === null) {
      return [];
    }

    return hazardUtils.siteClassesToParameters(
      usage.response.model.siteClasses,
    );
  });

  Number = Number;

  constructor(public service: AppService) {}
}
