import {Component, computed} from '@angular/core';
import {MatTab, MatTabContent, MatTabGroup} from '@angular/material/tabs';

import {AppService} from '../../services/app.service';
import {CurveDataComponent} from '../curve-data/curve-data.component';
import {PlotsComponent} from '../plots/plots.component';
import {SpectrumDataComponent} from '../spectrum-data/spectrum-data.component';

/**
 * Main content for application with tabs:
 *  - Plots tab: show static hazard plots
 *  - Hazard data tab: table of hazard data
 *  - Spectra data tab: table of spectra data
 */
@Component({
  imports: [
    MatTabGroup,
    MatTab,
    MatTabContent,
    PlotsComponent,
    CurveDataComponent,
    SpectrumDataComponent,
  ],
  selector: 'app-content',
  styleUrl: './content.component.scss',
  templateUrl: './content.component.html',
})
export class ContentComponent {
  /** Whether service has been called and has data */
  hasData = computed(() => this.service.serviceResponse() !== null);

  constructor(public service: AppService) {}
}
