import {Pipe, PipeTransform} from '@angular/core';

/**
 * Pipe to format logs based on log type.
 */
@Pipe({
  name: 'log',
  standalone: true,
})
export class LogPipe implements PipeTransform {
  ERROR = 'ERROR';
  INFO = 'INFO';
  WARNING = 'WARNING';
  RESULTS = 'Results: ';

  /**
   * Transform response log to formatted log.
   *
   * @param value The log
   */
  transform(value: string): string {
    if (value.includes(this.INFO)) {
      value = value.replace(
        new RegExp(this.INFO, 'gi'),
        `<span class="text-green">${this.INFO}</span>`,
      );
    } else if (value.includes(this.WARNING)) {
      value = value.replace(
        new RegExp(this.WARNING, 'gi'),
        `<span class="text-orange">${this.WARNING}</span>`,
      );
    } else if (value.includes(this.ERROR)) {
      value = value.replace(
        new RegExp(this.ERROR, 'gi'),
        `<span class="text-red">${this.ERROR}</span>`,
      );
    } else if (value.includes(this.RESULTS)) {
      const results = value.split(this.RESULTS).pop().trim();
      value = value.replace(
        new RegExp(`${this.RESULTS}${results}`, 'gi'),
        `<span class="text-bold">${this.RESULTS}<a href="${results}">${results}</a></span>`,
      );
    }

    return value;
  }
}
