import {Component, input, OnInit} from '@angular/core';
import * as YAML from 'yaml';

import {AppService} from '../../services/app.service';

export enum ExampleType {
  JSON = 'JSON',
  YAML = 'YAML',
}

/**
 * YAML or JSON example of HTTP POST to run hazard on AWS.
 */
@Component({
  selector: 'app-config-example',
  standalone: true,
  styleUrl: './config-example.component.scss',
  templateUrl: './config-example.component.html',
})
export class ConfigExampleComponent implements OnInit {
  /** The example type */
  readonly type = input<ExampleType>();

  /** JSON example */
  exampleJson = `\n${JSON.stringify(this.service.exampleConfig(), null, 2)}`;
  /** YAML example */
  exampleYml = `\n${YAML.stringify(this.service.exampleConfig(), {indent: 2})}`;
  /** The example to show */
  example = '';

  /** JSON example */
  exampleJsonArray = `\n${JSON.stringify(this.service.exampleConfigCalcArray(), null, 2)}`;
  /** YAML example */
  exampleYmlArray = `\n${YAML.stringify(this.service.exampleConfigCalcArray(), {indent: 2})}`;
  /** The example to show */
  exampleArray = '';

  constructor(private service: AppService) {}

  ngOnInit(): void {
    this.example =
      this.type() === ExampleType.YAML ? this.exampleYml : this.exampleJson;
    this.exampleArray =
      this.type() === ExampleType.YAML
        ? this.exampleYmlArray
        : this.exampleJsonArray;
  }
}
