import {Component, computed} from '@angular/core';
import {MatDivider} from '@angular/material/divider';
import {MatExpansionModule} from '@angular/material/expansion';
import {MatListModule} from '@angular/material/list';
import {
  NshmpLibNgDataTablePanelComponent,
  TableData,
} from '@ghsc/nshmp-lib-ng/nshmp';
import {NshmpPlot, plotUtils} from '@ghsc/nshmp-lib-ng/plot';
import {DataTitle} from 'plotly.js';

import {AppService} from '../../services/app.service';

interface Tables {
  tables: TableData[];
  title: string;
}

@Component({
  imports: [
    NshmpLibNgDataTablePanelComponent,
    MatExpansionModule,
    MatDivider,
    MatListModule,
  ],
  selector: 'app-data',
  styleUrl: './data.component.scss',
  templateUrl: './data.component.html',
})
export class DataComponent {
  results = computed(() => this.service.serviceResponse()?.response?.results);

  tables = computed(() => {
    const plots = this.service.plots();

    const tables: Tables[] = plots.temperature.plotData.data.map((_, index) => {
      const results = this.results()[index];
      const location = results.location;

      const tables: TableData[] = [
        ...this.toTableData(plots.temperature, index, false),
        ...this.toTableData(plots.porosity, index),
        ...this.toTableData(plots.vs, index),
        ...this.toTableData(plots.vp, index),
        ...this.toTableData(plots.density, index),
      ];

      return {
        tables,
        title: `Geophysical Profiles: ${location.latitude}°, ${location.longitude}°`,
      };
    });

    return tables;
  });

  constructor(private service: AppService) {}

  private toTableData(
    plot: NshmpPlot,
    index: number,
    hideX = true,
  ): TableData[] {
    const data = plot.plotData.data[index];

    return plotUtils.plotDataToTableData(
      {
        ...plot,
        plotData: {
          ...plot.plotData,
          data: [
            {
              ...data,
              x: data.y,
              y: data.x,
            },
          ],
        },
      },
      {
        hideX,
        xLabelTransform: () =>
          (plot.plotData.layout.yaxis.title as DataTitle).text,
        yLabelTransform: () =>
          (plot.plotData.layout.xaxis.title as DataTitle).text,
        yValueFormat: (y: number) => y.toFixed(4),
      },
    );
  }
}
