import {FaultSectionProperties} from '@ghsc/nshmp-utils-ts/libs/nshmp-haz/www/fault-sections-service';
import {
  FeaturesUsageResponse,
  FeatureType,
} from '@ghsc/nshmp-utils-ts/libs/nshmp-haz/www/features-service';
import {NshmMetadata} from '@ghsc/nshmp-utils-ts/libs/nshmp-haz/www/nshm-service';
import {SourceLogicTreesUsage} from '@ghsc/nshmp-utils-ts/libs/nshmp-haz/www/source-logic-trees-service';
import {Parameter} from '@ghsc/nshmp-utils-ts/libs/nshmp-ws-utils/metadata';
import * as L from 'leaflet';

import {EarthquakeFeatureProperties} from './earthquake-props.model';
import {HazardTile} from './hazard-tile.model';
import {Layers} from './layers.model';

/**
 * Data mapping application state.
 */
export interface AppState {
  /** Available NSHMs */
  availableModels: Parameter[];
  /** Map bounds */
  bounds: L.LatLngBounds;
  /** Earthqkaue popup info */
  earthquakeInfoPopupData: EarthquakeInfoPopupData;
  /** Hazard map tiles */
  hazardTiles: HazardTile[];
  /** Data for info popup */
  infoPopupData: InfoPopupData;
  /** Map layers */
  layers: Layers;
  /** Leaflet map */
  map: L.Map;
  /** Leaflet map options */
  mapOptions: L.MapOptions;
  /** NSHMs services */
  nshmServices: NshmMetadata[];
  /** Source features usage response */
  sourceFeaturesUsages: Map<string, FeaturesUsageResponse>;
  /** NSHMs MFD usages */
  treesUsageResponses: Map<string, SourceLogicTreesUsage>;
}

/**
 * Bottom sheet data for the info popup component.
 */
export interface InfoPopupData {
  /** GeoJSON feature */
  feature: GeoJSON.Feature<GeoJSON.Geometry, FaultSectionProperties>;
  /** Feature type */
  featureType: FeatureType;
}

export interface EarthquakeInfoPopupData {
  /** GeoJSON feature */
  feature: GeoJSON.Feature<GeoJSON.Point, EarthquakeFeatureProperties>;
}
