import {Signal} from '@angular/core';
import {FormGroup} from '@angular/forms';

/**
 * Application service interface to implement.
 */
export interface AppServiceModel<State, ControlForm> {
  /** Add form group validators */
  addValidators(): void;
  /** Call external service */
  callService(): void;
  /** Return default control panel form values */
  defaultFormValues(): ControlForm;
  /** Reactive form group */
  readonly formGroup: FormGroup;
  /** Initialize application */
  init(): void;
  /** Returns the initial state */
  initialState(): State;
  /** Application state signal */
  readonly state: Signal<State>;
  /**
   * Update state.
   *
   * @param state The updated state
   */
  updateState(state: Partial<State>): void;
}
