import {environment} from '../../environments/environment';
import {
  Applications,
  DevApplications,
  InternalApplications,
} from '../models/applications.model';

/** Main application name */
export const TOOLBOX_NAME = 'USGS Earthquake Hazard Toolbox';

/**
 * Returns all application info.
 */
export function apps(): Applications {
  return {
    dashboard: {
      display: 'Home',
      routerLink: '/',
    },
    designMaps: {
      dashboard: {
        display: 'Design Maps Dashboard',
        routerLink: '/designmaps',
        showInDashboard: false,
        showInMenu: false,
      },
      rtgm: {
        display: 'Risk-Targeted Ground Motion',
        routerLink: '/designmaps/rtgm',
      },
    },
    gmm: {
      dashboard: {
        display: 'GMM Dashboard',
        routerLink: '/gmm',
        showInDashboard: false,
        showInMenu: false,
      },
      distance: {
        display: 'Ground Motion vs. Distance',
        routerLink: '/gmm/distance',
      },
      magnitude: {
        display: 'Ground Motion vs. Magnitude',
        routerLink: '/gmm/magnitude',
      },
      spectra: {
        display: 'Response Spectra',
        routerLink: '/gmm/spectra',
      },
    },
    hazard: {
      dashboard: {
        display: 'Hazard Dashboard',
        routerLink: '/hazard',
        showInDashboard: false,
        showInMenu: false,
      },
      disagg: {
        display: 'Disaggregation',
        routerLink: '/hazard/disagg',
      },
      dynamic: {
        display: 'Hazard Curves (dynamic)',
        routerLink: '/hazard/dynamic',
      },
      static: {
        display: 'Hazard Curves (static)',
        routerLink: '/hazard/static',
      },
    },
    ncm: {
      dashboard: {
        display: 'NCM Dashboard',
        routerLink: '/ncm',
        showInDashboard: false,
        showInMenu: false,
      },
      geophysicalProfiles: {
        display: 'NCM Geophysical Profiles',
        routerLink: '/ncm/geophysical-profiles',
      },
    },
    services: {
      display: 'Services',
      isHref: true,
      routerLink: `${environment.webServices.baseUrl}/ws/nshmp/`,
    },
    source: {
      dashboard: {
        display: 'Source Model Dashboard',
        routerLink: '/source',
        showInDashboard: false,
        showInMenu: false,
      },
      data: {
        display: 'Model Maps',
        routerLink: '/source/model-maps',
      },
      mfd: {
        display: 'Magnitude Frequency Distribution',
        routerLink: '/source/mfd',
      },
      rateAndProbability: {
        display: 'Earthquake Rates and Probabilities',
        routerLink: '/source/rates',
      },
    },
  };
}

/**
 * Returns all the dev application info.
 */
export function devApps(): DevApplications {
  return {
    dashboard: {
      display: 'Development Dashboard',
      routerLink: '/dev',
      // showInMenu: false,
    },
    gmm: {
      dashboard: {
        display: 'Development GMM Dashboard',
        routerLink: '/dev/gmm',
        showInDashboard: false,
        showInMenu: false,
      },
      hangingWallEffects: {
        display: 'Hanging Wall Effects',
        routerLink: '/dev/gmm/hanging-wall-effects',
      },
    },
    hazard: {
      dashboard: {
        display: 'Development Hazard Dashboard',
        routerLink: '/dev/hazard',
        showInDashboard: false,
        showInMenu: false,
      },
      dynamicCompare: {
        display: 'Dynamic Hazard Compare',
        routerLink: '/dev/hazard/dynamic-compare',
      },
    },
    math: {
      dashboard: {
        display: 'Development Math Dashboard',
        routerLink: '/dev/math',
        showInDashboard: false,
        showInMenu: false,
      },
      exceedanceExplorer: {
        display: 'Exceedance Explorer',
        routerLink: '/dev/math/exceedance-explorer',
      },
    },
  };
}

/**
 * Returns all the dev application info.
 */
export function internalApps(): InternalApplications {
  return {
    aws: {
      dashboard: {
        display: 'Internal AWS Dashboard',
        routerLink: '/internal/aws',
        showInDashboard: false,
      },
      // eslint-disable-next-line sort-keys-fix/sort-keys-fix
      checkHazJobs: {
        display: 'Check nshmp-haz Jobs',
        routerLink: '/internal/aws/check-haz-jobs',
      },
      hazJobHistory: {
        display: 'nshmp-haz Job History',
        routerLink: '/internal/aws/haz-job-history',
      },
      submitHazJobs: {
        display: 'Submit nshmp-haz Jobs',
        routerLink: '/internal/aws/submit-haz-jobs',
      },
      terminateHazJobs: {
        display: 'Terminate nshmp-haz Jobs',
        routerLink: '/internal/aws/terminate-haz-jobs',
      },
    },
    dashboard: {
      display: 'Internal Dashboard',
      routerLink: '/internal',
    },
  };
}
