import {Navigation, NavigationList} from '@ghsc/nshmp-template';

import * as ApplicationsUtils from './applications.utils';

const APPS = ApplicationsUtils.apps();
const DEV_APPS = ApplicationsUtils.devApps();
const INTERNAL_APPS = ApplicationsUtils.internalApps();

/**
 * Returns the list of design map application.
 */
export function designMapApps(): Navigation[] {
  return Object.values(APPS.designMaps) as Navigation[];
}

export function devGmmApps(): Navigation[] {
  return Object.values(DEV_APPS.gmm) as Navigation[];
}

export function devHazardApps(): Navigation[] {
  return Object.values(DEV_APPS.hazard) as Navigation[];
}

/**
 * Returns the list development main applications.
 */
export function devMainApps(): Navigation[] {
  return [
    DEV_APPS.math.exceedanceExplorer,
    DEV_APPS.hazard.dynamicCompare,
    DEV_APPS.gmm.hangingWallEffects,
  ];
}

export function devMathApps(): Navigation[] {
  return Object.values(DEV_APPS.math) as Navigation[];
}

/**
 * Returns the drop down navigation menu for development applications.
 */
export function devNavigation(): NavigationList[] {
  const devNavigation: NavigationList[] = [
    {
      navigation: [DEV_APPS.dashboard],
    },
    {
      navigation: devHazardApps(),
      subHeader: 'Hazard',
    },
    {
      navigation: devGmmApps(),
      subHeader: 'Ground Motion Models',
    },
    {
      navigation: devMathApps(),
      subHeader: 'Math',
    },
  ];

  return [...devNavigation];
}

/**
 * Returns the list of ground motion model applications.
 */
export function gmmApps(): Navigation[] {
  return Object.values(APPS.gmm) as Navigation[];
}

/**
 * Returns list of hazard applications.
 */
export function hazardApps(): Navigation[] {
  return Object.values(APPS.hazard) as Navigation[];
}

/**
 * Returns the list of AWS applications.
 */
export function internalAwsApps(): Navigation[] {
  return Object.values(INTERNAL_APPS.aws) as Navigation[];
}

export function internalMainApps(): Navigation[] {
  return internalAwsApps();
}

export function internalNavigation(): NavigationList[] {
  const internalNavigation: NavigationList[] = [
    {
      navigation: [INTERNAL_APPS.dashboard],
    },
    {
      navigation: internalAwsApps(),
      subHeader: 'AWS',
    },
  ];

  return [...internalNavigation];
}

/**
 * Returns the list services apps.
 */
export function serviceApps(): Navigation[] {
  return [APPS.services];
}

/**
 * Returns drop down navigation menu of applications.
 */
export function navigation(): NavigationList[] {
  const navigation: NavigationList[] = [
    {
      navigation: [APPS.dashboard],
    },
    {
      navigation: hazardApps(),
      subHeader: 'Hazard',
    },
    {
      navigation: sourceModelApps(),
      subHeader: 'Source Models',
    },
    {
      navigation: gmmApps(),
      subHeader: 'Ground Motion Models',
    },
    {
      navigation: designMapApps(),
      subHeader: 'Design Map',
    },
    {
      navigation: ncmApps(),
      subHeader: 'National Crustal Model',
    },
    {
      navigation: [DEV_APPS.dashboard, ...devMainApps()],
      subHeader: 'Development',
    },
    {
      navigation: [APPS.services],
    },
  ];

  return [...navigation];
}

/**
 * Returns the list of NCM appliations.
 */
export function ncmApps(): Navigation[] {
  return Object.values(APPS.ncm) as Navigation[];
}

/**
 * Returns the list of source model applicaitons.
 */
export function sourceModelApps(): Navigation[] {
  return Object.values(APPS.source) as Navigation[];
}
