import {HttpClient} from '@angular/common/http';
import {Component, OnDestroy, OnInit} from '@angular/core';
import {RouterOutlet} from '@angular/router';
import {NshmpService} from '@ghsc/nshmp-lib-ng/nshmp';
import {VersionInfo} from '@ghsc/nshmp-utils-ts/libs/nshmp-ws-utils';
import {TOOLBOX_NAME} from 'projects/nshmp-apps/src/shared/utils/applications.utils';
import {Subscription} from 'rxjs';

/**
 * USGS Earthquake Hazard Toolbox application router outlet for all applications.
 *
 * @see {@link app-routing.module.ts}
 */
@Component({
  imports: [RouterOutlet],
  selector: 'app-root',
  styleUrl: './app.component.scss',
  templateUrl: './app.component.html',
})
export class AppComponent implements OnInit, OnDestroy {
  versionSubscription: Subscription;

  constructor(
    private nshmpService: NshmpService,
    private http: HttpClient,
  ) {}

  ngOnInit(): void {
    // Set toolbox name
    this.nshmpService.toolboxName = TOOLBOX_NAME;

    // Set version info
    this.versionSubscription = this.http
      .get<VersionInfo>('assets/nshmp-apps-version.json')
      .subscribe(versionInfo => {
        this.nshmpService.versionInfo = versionInfo;
      });
  }

  ngOnDestroy(): void {
    this.versionSubscription?.unsubscribe();
  }
}
