import {Injectable} from '@angular/core';
import {HazardService} from '@ghsc/nshmp-lib-ng/hazard';
import {Navigation, NavigationList} from '@ghsc/nshmp-template';
import {environment} from 'projects/nshmp-apps/src/environments/environment';
import {WebServiceConfig} from 'projects/nshmp-apps/src/shared/models/web-services.model';
import {forkJoin, map, Observable} from 'rxjs';

@Injectable({
  providedIn: 'root',
})
export class NavigationService {
  navigationList: NavigationList[] = [];

  private webServices = environment.webServices;

  constructor(private hazardService: HazardService) {
    this.navigation();
  }

  private navigation(): void {
    forkJoin([this.dynamicazardServices$(), this.staticHazardServices$()])
      .pipe(
        map(([dynamicServices, staticServices]) => {
          const navigation: NavigationList[] = [
            {
              navigation: [
                {
                  display: 'Home',
                  isHref: true,
                  routerLink: '/ws/nshmp',
                },
              ],
            },
            {
              navigation: dynamicServices,
              subHeader: 'Dynamic Hazard Web Services',
            },
            {
              navigation: staticServices,
              subHeader: 'Static Hazard Web Services',
            },
            {
              navigation: [this.serviceToNav(this.webServices.gmm)],
              subHeader: 'Ground Motion Model Web Services',
            },
            {
              navigation: [this.serviceToNav(this.webServices.ncm)],
              subHeader: 'National Crustal Model Web Services',
            },
            {
              navigation: [
                this.serviceToNav(this.webServices.rtgm),
                this.serviceToNav(this.webServices.aashto2023),
                this.serviceToNav(this.webServices.asce4123),
              ],
              subHeader: 'Designmap Web Services',
            },
          ];

          return navigation;
        }),
      )
      .subscribe(navigationList => {
        this.navigationList = navigationList;
      });
  }

  private contextPath(contextPath: string): string {
    return contextPath.replace('/ws/nshmp', '');
  }

  private dynamicazardServices$(): Observable<Navigation[]> {
    const nshmpHazWs = environment.webServices.nshmpHazWs;

    return this.hazardService
      .dynamicNshmService$(`${nshmpHazWs.url}${nshmpHazWs.services.nshms}`)
      .pipe(
        map(usage => {
          return usage.response.map(nshm => ({
            display: nshm.label,
            isHref: true,
            routerLink: nshm.url.split('.gov').pop(),
          }));
        }),
      );
  }

  private serviceToNav(service: WebServiceConfig<unknown>): Navigation {
    return {
      display: service.label,
      isHref: true,
      routerLink: service.contextPath,
    };
  }

  private staticHazardServices$(): Observable<Navigation[]> {
    const nshmpWsStatic = environment.webServices.nshmpWsStatic;

    return this.hazardService
      .staticNshmService$(`${nshmpWsStatic.url}${nshmpWsStatic.services.nshms}`)
      .pipe(
        map(usage => {
          return usage.response.map(nshm => ({
            display: nshm.label,
            isHref: true,
            routerLink: nshm.url.split('.gov').pop(),
          }));
        }),
      );
  }
}
