import {HttpClient} from '@angular/common/http';
import {
  Component,
  ElementRef,
  OnInit,
  viewChild,
  ViewEncapsulation,
} from '@angular/core';
import {MatDialogRef} from '@angular/material/dialog';
import {
  NshmpLibNgAboutContentComponent,
  NshmpLibNgAboutDescriptionComponent,
  NshmpLibNgAboutDescriptionTitleComponent,
  NshmpLibNgAboutPageComponent,
} from '@ghsc/nshmp-lib-ng/about';
import {
  AlertType,
  NshmpLibNgAlertComponent,
  NshmpLibNgSpinnerComponent,
  NshmpLibNgTemplateComponent,
  NshmpService,
  SpinnerService,
} from '@ghsc/nshmp-lib-ng/nshmp';
import {NavigationService} from 'projects/nshmp-ws/src/app/navigation.service';
import {catchError} from 'rxjs';
import {Spec, SwaggerUIBundle} from 'swagger-ui-dist';

@Component({
  encapsulation: ViewEncapsulation.None,
  imports: [
    NshmpLibNgTemplateComponent,
    NshmpLibNgAlertComponent,
    NshmpLibNgAboutPageComponent,
    NshmpLibNgAboutContentComponent,
    NshmpLibNgAboutDescriptionComponent,
    NshmpLibNgAboutDescriptionTitleComponent,
  ],
  selector: 'app-app',
  styleUrl: './app.component.scss',
  templateUrl: './app.component.html',
})
export class AppComponent implements OnInit {
  /** Application title */
  title = '';

  AlerType = AlertType;

  swagger = viewChild<ElementRef<HTMLElement>>('swagger');

  private spinnerRef: MatDialogRef<NshmpLibNgSpinnerComponent>;

  constructor(
    public navigationService: NavigationService,
    private spinnerService: SpinnerService,
    private httpClient: HttpClient,
    private nshmpService: NshmpService,
  ) {}

  ngOnInit(): void {
    this.spinnerRef = this.spinnerService.show('Loading ...');

    const contextPath = location.pathname;
    const url = `${location.href}/swagger`;

    // Check swagger endpoint first
    this.httpClient
      .get(url, {
        responseType: 'text',
      })
      .pipe(
        catchError((error: Error) => {
          this.spinnerRef.close();
          return this.nshmpService.throwError$(
            new Error(`Failed to get swagger endpoint. ${error.message}`),
          );
        }),
      )
      .subscribe(() => {
        SwaggerUIBundle({
          deepLinking: false,
          defaultModelsExpandDepth: 0,
          domNode: this.swagger().nativeElement,
          layout: 'BaseLayout',
          plugins: [
            // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
            SwaggerUIBundle?.plugins?.DownloadUrl,
            this.updateContextPath(contextPath),
          ],
          // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
          presets: [SwaggerUIBundle?.presets?.apis],
          tagsSorter: 'alpha',
          tryItOutEnabled: true,
          url,
          validatorUrl: null,
        });
      });
  }

  updateContextPath(contextPath: string) {
    return {
      statePlugins: {
        spec: {
          wrapActions: {
            updateJsonSpec:
              (oriAction: (...args: Spec[]) => unknown) =>
              (...args: Spec[]) => {
                this.spinnerRef?.close();
                const [spec] = args;
                if (spec && spec.info) {
                  this.title = (spec.info as Record<string, string>)?.title;
                }
                if (spec && spec.paths) {
                  const newPaths: Record<string, string> = {};
                  // eslint-disable-next-line @typescript-eslint/no-unsafe-argument
                  Object.entries(spec.paths).forEach(([path, value]) => {
                    contextPath =
                      contextPath.endsWith('/') && path.startsWith('/')
                        ? contextPath.slice(0, -1)
                        : contextPath;

                    const servicePath = path.includes(contextPath)
                      ? path
                      : `${contextPath}${path}`;
                    newPaths[servicePath] = value as string;
                  });
                  spec.paths = newPaths;
                }
                oriAction(...args);
              },
          },
        },
      },
    };
  }
}
