#!/bin/bash
#
# Build compodocs for all applications, projects/nshmp-apps
#
# See https://compodoc.app
####

FAVICON_PATH="${FAVICON_PATH:-../nshmp-apps/src/assets/favicon.ico}";
THEME="${THEME:-material}";

pushd projects/nshmp-apps > /dev/null 2>&1 || {
  printf "\nFailed to change to nshmp-apps directory";
  exit 1;
};

while IFS= read -r -d '' file; do
  project_dir="$(dirname "${file}")";
  project="$(basename "${project_dir}")";
  nshmp_apps_dir="$(echo "${project_dir}" | awk -F/ -v OFS=/ '{gsub(/[\dA-Za-z0-9\-]*/,".."); print}')";
  output="${nshmp_apps_dir}/../../compodoc/apps/${project_dir/src\/app\//}";

  pushd "${project_dir}" > /dev/null 2>&1 || {
    printf "\nFailed to change to [%s] directory\n" "${project_dir}";
    exit 1;
  };

  printf "\nBuilding %s application documentation\n" "${project}";

  npm run compodoc -- \
      --config=".compodoc.yml" \
      --customFavicon="${nshmp_apps_dir}/${FAVICON_PATH}" \
      --disableDependencies \
      --hideGenerator \
      --output="${output}" \
      --theme="${THEME}" \
      --tsconfig="tsconfig.doc.json" || {
    printf "\nFailied to build compodocs in project [%s]\n" "${project}";
    exit 1;
  };

  popd > /dev/null 2>&1 || {
    printf "\nFailed to pop back from [%s]\n" "${project_dir}";
    exit 1;
  };
done < <(find src/app -name '.compodoc.yml' -print0)

npm run compodoc -- \
    --config=".compodoc.yml" \
    --customFavicon="${FAVICON_PATH}" \
    --disableDependencies \
    --hideGenerator \
    --output="../../compodoc/apps" \
    --theme="${THEME}" \
    --tsconfig="tsconfig.doc.json" || {
  printf "\nFailied to build compodocs in projects/nshmp-apps";
  exit 1;
};

popd > /dev/null 2>&1 || {
  printf "\nFailed to pop back to repo root directory";
  exit 1;
};
